<template>
  <div class="riskBox">
    <el-form ref="formRef" :model="state.formData" :rules="state.rules" class="register-form" label-position="top">
      <el-row :gutter="30">
        <el-col :span="6">
          <el-form-item prop="transmitDate" label="审核日期">
            <el-date-picker
                style="width: 100%"
                v-model="state.formData.transmitDate"
                type="date"
                value-format="YYYY-MM-DD 00:00:00"
                placeholder="选择日期"
                size="large"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item prop="leader.name" label="过程控制负责人">
            <el-input
                v-model="state.formData.leader.name"
                size="large"
                placeholder="请选择内部审核员"
            >
              <template #append>
                <el-button :icon="Search" @click="openExperts('过程控制负责人')"/>
              </template>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="8">
          <el-form-item prop="technology" label="审核结论：是否满足过程控制要求">
            <el-radio-group v-model="state.formData.status" >
              <el-radio :label="1">是</el-radio>
              <el-radio :label="0">否</el-radio>
            </el-radio-group>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="30">
        <el-col :span="6">
          <el-form-item >
            <el-upload accept=".pdf,.doc,.docx"
                       :action="state.uploadUrl"
                       :disabled="state.disabled"
                       :headers="state.header"
                       method="post"
                       :on-success="handleAvatarSuccess"
                       v-model:file-list="state.fileList"
                       :on-remove="handleRemove"
                       :data="state.uploadData"
                       :on-preview="handlePreview"
            >
              <el-button type="primary">附件上传</el-button>
            </el-upload>
          </el-form-item>
        </el-col>
      </el-row>
      <el-table  :data="state.tableData" :border="true" style="margin-bottom: 20px">
        <el-table-column label="序号" width="60" align="center" type="index"></el-table-column>
        <el-table-column label="过程控制关键点" prop="content" header-align="center" :show-overflow-tooltip="true"/>
        <el-table-column label="审核结果" header-align="center" class-name="small-padding fixed-width" width="175">
          <template #default="scope">
            <el-radio-group v-model="scope.row.status" >
              <el-radio :label="1">符合</el-radio>
              <el-radio :label="0">不符合</el-radio>
            </el-radio-group>
          </template>
        </el-table-column>
        <el-table-column label="不符合描述" header-align="center" class-name="small-padding fixed-width" width="700">
          <template #default="scope">
            <el-input
                v-model="state.formData.leader.name"
                size="large"
                disabled
                placeholder="如不符合，请填写不符合描述"
            />
          </template>
        </el-table-column>
      </el-table>
      <el-form-item prop="technology" label="存在问题及建议">
        <el-input
            v-model="state.formData.technology"
            :autosize="{ minRows: 6 }"
            maxlength="500"
            show-word-limit
            type="textarea">
        </el-input>
      </el-form-item>
    </el-form>
    <el-dialog v-model="state.dialogImg">
      <el-image style="width: 100%; height: 100%" :src="state.dialogImageUrl"/>
    </el-dialog>
    <experts-list ref="expertsListRef" @getName="getSelected"></experts-list>
  </div>
</template>
<script setup>

import {defineEmits, onMounted, reactive, ref} from "vue";
import {ElMessage} from "element-plus";
import {Search} from '@element-plus/icons-vue'
import {addRisk, editRisk, getRiskDetail} from "@/api/projectManage/riskAnalysis"
import {delPic} from "@/api/login"
import { getToken } from "@/utils/auth";
import Cookies from "js-cookie"
import ExpertsList from "./expertsList";
import axios from "axios";
import {delAccessoryFile} from "@/api/projectManage/project";
const emit = defineEmits(["getNextStatus"]);

const state = reactive({
  formData: {
    id: '',
    leader: {
      name: ''
    },
    leaderId: null,
    linkMan: '',
    transmitPerson: '',
    transmitDate: ''
  },
  rules: {
    "leader.name": [{required: true, message: '请选择项目负责人', trigger: 'blur'}],
    linkMan: [{required: true, message: '请输入联系人', trigger: 'blur'}],
    linkPhone: [{required: true, message: '请输入联系电话', trigger: 'blur'}],
    transmitDate: [{required: true, message: '请选择任务下达时间', trigger: 'blur'}]
  },
  tableData: [
    {id: 1, content: '报告中所列评价依据是否得到引用和验证', status: 1},
    {id: 2, content: '现场收集的有关资料是否齐全、有效', status: 1},
    {id: 3, content: '危险有害因素识别是否充分', status: 1},
    {id: 4, content: '报告是否有重大遗漏', status: 0},
    {id: 5, content: '评价方法选用是否合理', status: 1},
    {id: 6, content: '对策措施及建议是否具有针对性、合理性', status: 1},
    {id: 7, content: '评价结论及格式是否正确', status: 1},
    {id: 8, content: '已按要求修改完成', status: 1},
    {id: 9, content: '可报过程控制负责人审核', status: 1}
  ],
  imgLimit: 1,
  uploadUrl: import.meta.env.VITE_APP_BASE_API + '/manage/accessory-file/uploadFile',
  header: {
    Authorization: getToken()
  },
  dialogImageUrl: '',
  dialogImg: false,
  uploadData: {
    moduleType: 8
  },
  disabled: false
})
const props = {
  expandTrigger: 'hover',
  value: 'name',
  label: 'name'
}
const isAmin = ref(false)
const formRef = ref()
const expertsListRef = ref()
onMounted(() => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  if(userInfo.identity === 0){
    isAmin.value = true;
  }
  if(Cookies.get('projectId')){
    state.uploadData.projectId = Cookies.get('projectId')
  }
})

const riskOpen = async (type,val) => {
  state.uploadData.projectId = val;
  if(type === 'detail' || type === 'edit' ){
    const res = await getRiskDetail({projectId: val});
    if(res.code == 200){
      state.formData = res.data;
    }else {
      ElMessage.warning(res.message)
    }
  }
  if(type === 'add' || type === 'clickEdit') {
    const valid = await formRef.value.validate();
    if(valid){
      if (isAmin.value) {
        ElMessage.warning("当前用户暂无权限");
        return;
      }
      if(type === 'add'){
        const {id, ...data} = JSON.parse(JSON.stringify(state.formData))
        const res = await addRisk(data);
        if (res.code == 200) {
          ElMessage.success('保存成功')
          formRef.value.clearValidate();
          emit('getNextStatus', res.data);

        } else {
          ElMessage.warning(res.message)
        }
      }else if(type === 'clickEdit'){
        const { ...data} = JSON.parse(JSON.stringify(state.formData))
        const res = await editRisk(data);
        if (res.code == 200) {
          ElMessage.success('变更成功')
          formRef.value.clearValidate();
          // emit('getNextStatus', data.project.id);
        } else {
          ElMessage.warning(res.message)
        }
      }
    }
  }
}

const openExperts = (type) =>{
  expertsListRef.value.openDialog(type)
}

const getSelected = (type,obj)=>{
  state.formData.leader.name = obj.name
  state.formData.leaderId = obj.id
}

const handleAvatarSuccess = (res) => {
  if(res.code === 200){
    console.log("if",state.fileList)
    ElMessage({
      type: 'success',
      message: '文件上传成功'
    })
  }else {
    ElMessage({
      type: 'warning',
      message: '文件上传失败'
    })
  }
}
const handlePreview = (file) => {
  let path = "";
  if(file.path){
    path = file.path
  }else {
    path = file.response.data.path

  }
  const url = import.meta.env.VITE_APP_BASE_API + '/' + path
  axios.get( url,{
        headers:
            {
              'Content-Type': 'application/json',
              'Authorization':getToken(),
            },
        responseType: 'blob'
      }
  ).then(res=>{
    if (res) {
      const link = document.createElement('a')
      let blob = new Blob([res.data],{type: res.data.type})
      link.style.display = "none";
      link.href = URL.createObjectURL(blob); // 创建URL
      link.setAttribute("download", file.name);
      document.body.appendChild(link);
      link.click();
      document.body.removeChild(link);
    } else {
      this.$message.error('获取文件失败')
    }
  })
}

const handleRemove = async (file, uploadFiles) => {
  console.log("file",file)
  let accessoryFileId = "";
  if(file.id){
    accessoryFileId = file.id
  }else {
    accessoryFileId = file.response.data.id

  }
  const res = await delAccessoryFile(accessoryFileId)
  if(res.code == 200){
    ElMessage({
      type: 'success',
      message: '文件已删除'
    })
  }else{
    ElMessage({
      type: 'warning',
      message: res.message
    })
  }
}

defineExpose({
  riskOpen
});


</script>
<style scoped lang="scss">
.riskBox{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
}

</style>
